<template>
  <div class="mod-config">
    <basic-container>
      <el-form :inline="true" :model="dataForm" @keyup.enter.native="getDataList()">
        <el-form-item>
          <el-button v-if="permissions.market_person_add" icon="el-icon-plus" type="primary" @click="addOrUpdateHandle()">新增</el-button>
          <el-button icon="el-icon-bottom" type="primary">导入数据</el-button>
        </el-form-item>
      </el-form>
      <div class="law-search-box">
        <el-row :gutter="40">
          <el-col :span="6">
            <el-input clearable v-model.trim="searchForm.name" suffix-icon="el-icon-search" placeholder="请输入自然人姓名"></el-input>
          </el-col>
          <el-col :span="5">
            <el-input clearable v-model.trim="searchForm.cardNo" suffix-icon="el-icon-search" placeholder="身份证号码"></el-input>
            <!--<el-date-picker
              placeholder="身份证号码"
              style="width: 100%"
              type="date"
              v-model="searchForm.cardNo">
            </el-date-picker>-->
          </el-col>
          <el-col :span="5">
            <el-button @click="searchHadleBtn" type="primary">搜索</el-button>
          </el-col>
          <!--<el-col :span="5">
            <div class="sort-box">
              <img src="../../../assets/lawImg/sortIcon.png" alt="">
              <h1>违法数量由高至低排列</h1>
            </div>
          </el-col>-->

        </el-row>
      </div>
      <div class="avue-crud">
        <el-table
                :data="dataList"
                border
                v-loading="dataListLoading">
                      <el-table-column
                    prop="id"
                    header-align="center"
                    align="center"
                    label="序号">
            </el-table-column>
                      <el-table-column
                    prop="name"
                    header-align="center"
                    align="center"
                    label="姓名">
            </el-table-column>
                      <el-table-column
                    prop="sex"
                    header-align="center"
                    align="center"
                    label="性别">
            </el-table-column>
                      <el-table-column
                    prop="nation"
                    header-align="center"
                    align="center"
                    label="民族">
            </el-table-column>
                      <el-table-column
                    prop="birthday"
                    header-align="center"
                    align="center"
                    label="出生日期">
            </el-table-column>
                      <el-table-column
                    prop="address"
                    header-align="center"
                    align="center"
                    label="住址">
            </el-table-column>
                      <el-table-column
                    prop="cardNo"
                    header-align="center"
                    align="center"
                    label="身份证号">
            </el-table-column>
                      <el-table-column
                    prop="lawNum"
                    header-align="center"
                    align="center"
                    label="违法总数">
            </el-table-column>
                    <el-table-column
                  header-align="center"
                  align="center"
                  label="操作">
            <template slot-scope="scope">
              <el-button v-if="permissions.market_person_edit" type="text" size="small" icon="el-icon-edit" @click="addOrUpdateHandle(scope.row.id)">修改</el-button>
              <el-button v-if="permissions.market_person_del" type="text" size="small" icon="el-icon-delete" @click="deleteHandle(scope.row.id)">删除</el-button>
            </template>
          </el-table-column>
        </el-table>
      </div>

      <div class="avue-crud__pagination">
        <el-pagination
                @size-change="sizeChangeHandle"
                @current-change="currentChangeHandle"
                :current-page="pageIndex"
                :page-sizes="[10, 20, 50, 100]"
                :page-size="pageSize"
                :total="totalPage"
                background
                layout="total, sizes, prev, pager, next, jumper">
        </el-pagination>
      </div>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getDataList"></table-form>
    </basic-container>
  </div>
</template>

<script>
  import {fetchList, delObj} from '@/api/person'
  import TableForm from './person-form'
  import {mapGetters} from 'vuex'
  export default {
    data () {
      return {
        dataForm: {
          key: ''
        },
        searchForm: {
            name:'',
            cardNo:''
        },
        dataList: [],
        pageIndex: 1,
        pageSize: 10,
        totalPage: 0,
        dataListLoading: false,
        addOrUpdateVisible: false
      }
    },
    components: {
      TableForm
    },
    created () {
      this.getDataList()
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
        searchHadleBtn() {
            this.getDataList()
        },
      // 获取数据列表
      getDataList () {
        this.dataListLoading = true
        fetchList(Object.assign({
          current: this.pageIndex,
          size: this.pageSize
        },this.searchForm)).then(response => {
          this.dataList = response.data.data.records
          this.totalPage = response.data.data.total
        })
        this.dataListLoading = false
      },
      // 每页数
      sizeChangeHandle (val) {
        this.pageSize = val
        this.pageIndex = 1
        this.getDataList()
      },
      // 当前页
      currentChangeHandle (val) {
        this.pageIndex = val
        this.getDataList()
      },
      // 新增 / 修改
      addOrUpdateHandle (id) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(id)
        })
      },
      // 删除
      deleteHandle (id) {
        this.$confirm('是否确认删除ID为' + id, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(function () {
          return delObj(id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getDataList()
        })
      }
    }
  }
</script>

<style scoped>
  .law-search-box{
    margin-bottom:20px;
  }
</style>
